#!/bin/sh

echo ""
echo "IBM Business Process Manager 8.0.1 Upgrade"
echo ""

usage() {
  echo -e -n "\n"
  echo "Starts or continues the upgrade."
  echo -e -n "\n"
  echo "Usage:"
  echo -e -n "\n"
  echo "   `basename ${0}` [options...]"
  echo -e -n "\n"
  echo "Options:"
  echo "   -?, -help                             This help message"
  echo "   -profileName <name>                   Profile name"
  echo "   -nodeName <name>                      Node name in ND environment"
  echo "   -serverName <name>                    Server name in ND environment"
  echo "   -perfNodeName <name>                  Specified node name of Performance Data Warehouse in ND environment (optional)"
  echo "   -perfServerName <name>                Specified server name of Performance Data Warehouse in ND environment (optional)"
  echo "   -wasHome <WAS home>                   Location of WAS install directory"
  echo "   -noPrompt                             Set -noPrompt flag to make the tool work with no interaction. If you do not set this parameter, the tool will prompt you to confirm (optional)"		
  echo "   -ifix <ifix list separated by ,>      Specify '-ifix JRXXXXX,JRYYYYY' to update database for ifix"
  echo -e -n "\n"
  exit $1
}

validateParam() {
  if [ "$2" = "" ]
  then
    echo "No value specified for parameter $1"
    usage 1
  fi
}

NODE_NAME_PROP=
SERVER_NAME_PROP=
UPGRADECOMMAND_PROP="-Dupgradecommand=$0 $*"

ENABLE_DEBUG=false
if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-Xdebug -Xrunjdwp:transport=dt_socket,address=7780,server=y,suspend=y"   
else
   DEBUG_PROP= 
fi

FINISHED='0'
until [ $FINISHED = '1' ]
do
  case "$1" in
    '-?'|'-help')
      usage 0
      ;;
    '-profileName')
      validateParam $1 $2
      shift;shift
      ;;
    '-nodeName')
      validateParam $1 $2
      NODE_NAME_PROP="-DnodeName=$2"
      shift;shift
      ;;
    '-serverName')
      validateParam $1 $2
      SERVER_NAME_PROP="-DserverName=$2"
      shift;shift
      ;;
    '-perfNodeName')
      validateParam $1 $2
      PERF_NODE_NAME_PROP="-DperfNodeName=$2"
      shift;shift
      ;;
    '-perfServerName')
      validateParam $1 $2
      PERF_SERVER_NAME_PROP="-DperfServerName=$2"
      shift;shift
      ;;
    '-wasHome')
      validateParam $1 $2
      wasHome=$2
      shift;shift
      ;;
    '-ifix')
      validateParam $1 $2
      IFIX_TO_INSTALL="-Difix=$2"
      shift;shift
      ;;
    '-noPrompt')
      NO_PROMPT_PROP="-DnoPrompt=true"
      shift
      ;;
    *)
      if [ "$1" != "" ]
      then
        echo "Invalid parameter: $1, please correct it and try again."
        usage 1
      fi
      FINISHED='1'
      ;;
  esac
done

SCRIPT_DIR=`dirname ${0}`
ORIG_DIR=`pwd`
BIN_DIR=$SCRIPT_DIR/../../../../../bin
if [ -z $wasHome ] ; then
  REPLACE_WAS_HOME=$SCRIPT_DIR/../../../../../
else
  REPLACE_WAS_HOME=$wasHome
fi
. $BIN_DIR/setupCmdLine.sh


if [ "${USER_INSTALL_ROOT:=}" = "" ]; then
  echo -e -n "\n"
  echo "Profile does not exist."
  echo -e -n "\n"
  usage 1
fi

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

WAS_HOME_PROP="-Dwas.install.root=${WAS_HOME}"
APP_JAVA_POLICY="-Djava.security.policy=file:${SCRIPT_DIR}/java.policy"
LOGGING_PROP="-Dcom.lombardisoftware.ant.JULDefaultLogger.level=DEBUG -Djava.util.logging.config.file=$SCRIPT_DIR/logging.properties -Dtw.log4j.init=false"
LOGGING_FILTER_PROP="-Dcom.lombardi.logging.StringFilter.excludes=contains(db.password);equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500);regexp(^Class.+loaded.from.ant.loader..parentFirst.);regexp(^Class.+loaded.from.parent.loader..parentFirst.);regexp(^Finding.class.+\..+\..+);regexp(^Loaded.from.+\.jar..+\.class$)"
LOGGING_PROP="$LOGGING_PROP $LOGGING_FILTER_PROP"
ANT_PROPS="-q -e -logger com.lombardisoftware.ant.JULDefaultLogger"

CLASSPATH=$SCRIPT_DIR
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant.jar
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant-launcher.jar
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant-nodeps.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/ant-contrib.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/twant.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/langutil.jar

$JAVA_EXE -cp $CLASSPATH $WAS_HOME_PROP $APP_JAVA_POLICY $USER_INSTALL_PROP $NODE_NAME_PROP $SERVER_NAME_PROP $PERF_NODE_NAME_PROP $PERF_SERVER_NAME_PROP $NO_PROMPT_PROP  $LOGGING_PROP $DEBUG_PROP $IFIX_TO_INSTALL "$UPGRADECOMMAND_PROP" org.apache.tools.ant.Main -buildfile $SCRIPT_DIR/upgrade.xml $ANT_PROPS

if [ "$?" -ne "0" ]
then
  exit $?
fi
